@@ -17,9 +17,9 @@ class DolphinDBKernel(Kernel):
     language = 'python'
     language_version = '1.0'
     language_info = {
-        'name': 'python',
-        'mimetype': 'text/plain',
-        'file_extension': '.py',
+        'name': 'sql',
+        'mimetype': 'text/x-mysql'
+        # 'file_extension': '.py',
     }
     banner = "DolphinDB Kernel"
     s = ddb.session()
